"""
This module contains code related to the graphical user interface.
"""
from .main import main


def run_gui():
    main()
